imblearn.under_sampling.InstanceHardnessThreshold
=================================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: InstanceHardnessThreshold

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~InstanceHardnessThreshold.__init__
      ~InstanceHardnessThreshold.fit
      ~InstanceHardnessThreshold.fit_sample
      ~InstanceHardnessThreshold.get_params
      ~InstanceHardnessThreshold.sample
      ~InstanceHardnessThreshold.set_params
   
   

   
   
   